@@ -32,7 +32,7 @@ tcplLoadUnit <- function(aeid) {
   
   qstring <- sprintf(qformat, paste(aeid, collapse = ","))
   
-  dat <- tcplQuery(query = qstring, db = getOption("TCPL_DB"))
+  dat <- tcplQuery(query = qstring, db = getOption("TCPL_DB"), tbl=c("assay_component_endpoint"))
   
   if (nrow(dat) == 0) {
     warning("The given aeid(s) do not have response units.")
