@@ -5,14 +5,14 @@
 #' @rdname query_funcs
 #' 
 #' @import DBI
-#' @importFrom RSQLite SQLite 
 #' @import data.table
 #' @importFrom RMySQL MySQL
+#' @importFrom sqldf sqldf
+#' @importMethodsFrom RMySQL dbConnect dbDisconnect
 #' @export
 
-
 tcplQuery <- function(query, db = getOption("TCPL_DB"), 
-                      drvr = getOption("TCPL_DRVR")) {
+                      drvr = getOption("TCPL_DRVR"), tbl=NULL) {
   
   if (is.null(db)) db <- getOption("TCPL_DB")
   if (is.null(drvr)) drvr <- getOption("TCPL_DRVR")
@@ -27,13 +27,6 @@ tcplQuery <- function(query, db = getOption("TCPL_DB"),
   
   db_pars <- NULL
   
-  if (drvr == "SQLite") {
-    
-    db_pars <- list(drv = SQLite(),
-                    dbname = db)
-    
-  }
-  
   if (drvr == "MySQL") {
     
     if (any(is.na(options()[c("TCPL_USER", "TCPL_HOST", "TCPL_PASS")]))) {
@@ -49,6 +42,20 @@ tcplQuery <- function(query, db = getOption("TCPL_DB"),
     
   }
   
+  if (drvr == "tcplLite") {
+    #query <- "SELECT spid,chemical.chid,casn,chnm FROM sample LEFT JOIN chemical ON chemical.chid=sample.chid WHERE sample.chid is NULL  "
+    db_pars <- "Just running tcplLite, we're OK"
+    for (t in tbl) {
+      fpath <- paste(db, t, sep='/')
+      fpath <- paste(fpath, 'csv', sep='.')
+      assign(t, read.table(fpath, header=T, sep=','))
+    }
+
+    result <- as.data.table(sqldf(query, stringsAsFactors=F))
+
+    
+  }
+  
   if (is.null(db_pars)) {
     
     stop(getOption("TCPL_DRVR"), " is not a supported database system. See ",
@@ -56,12 +63,15 @@ tcplQuery <- function(query, db = getOption("TCPL_DB"),
     
   }
   
-  dbcon <- do.call(dbConnect, db_pars)
-  result <- DBI::dbGetQuery(dbcon, query)
+  if (drvr == 'MySQL') {
+    dbcon <- do.call(dbConnect, db_pars)
+    result <- dbGetQuery(dbcon, query)
+    
+    dbDisconnect(dbcon)
+    
+    result <- as.data.table(result)
+  }
   
-  dbDisconnect(dbcon)
-  
-  result <- as.data.table(result)
   result[]
   
 }
